@@ -162,6 +162,7 @@ void
 ags_pattern_envelope_init(AgsPatternEnvelope *pattern_envelope)
 {
   GtkGrid *grid;
+  GtkBox *vbox;
   GtkBox *hbox;
   GtkBox *control;
   AgsCartesian *cartesian;
@@ -190,6 +191,14 @@ ags_pattern_envelope_init(AgsPatternEnvelope *pattern_envelope)
   gtk_box_set_spacing((GtkBox *) pattern_envelope,
 		      AGS_UI_PROVIDER_DEFAULT_SPACING);
 
+  gtk_widget_set_vexpand((GtkWidget *) pattern_envelope,
+			 TRUE);
+  gtk_widget_set_hexpand((GtkWidget *) pattern_envelope,
+			 TRUE);
+
+  gtk_widget_set_valign((GtkWidget *) pattern_envelope,
+			GTK_ALIGN_START);
+
   pattern_envelope->flags = 0;
 
   pattern_envelope->version = AGS_PATTERN_ENVELOPE_DEFAULT_VERSION;
@@ -469,10 +478,41 @@ ags_pattern_envelope_init(AgsPatternEnvelope *pattern_envelope)
 
   i++;
   
+  /* vbox */
+  vbox = (GtkBox *) gtk_box_new(GTK_ORIENTATION_VERTICAL,
+				AGS_UI_PROVIDER_DEFAULT_SPACING);
+  
+  gtk_widget_set_vexpand((GtkWidget *) vbox,
+			 TRUE);
+  gtk_widget_set_hexpand((GtkWidget *) vbox,
+			 TRUE);
+
+  gtk_widget_set_valign((GtkWidget *) vbox,
+			GTK_ALIGN_START);
+
+  gtk_box_append((GtkBox *) pattern_envelope,
+		 (GtkWidget *) vbox);
+
   /* grid */
   grid = (GtkGrid *) gtk_grid_new();
-  gtk_box_append((GtkBox *) pattern_envelope,
-		 GTK_WIDGET(grid));
+
+  gtk_widget_set_vexpand((GtkWidget *) grid,
+			 FALSE);
+  gtk_widget_set_hexpand((GtkWidget *) grid,
+			 TRUE);
+
+  gtk_widget_set_halign((GtkWidget *) grid,
+			GTK_ALIGN_START);
+  gtk_widget_set_valign((GtkWidget *) grid,
+			GTK_ALIGN_START);
+
+  gtk_grid_set_column_spacing(grid,
+			      AGS_UI_PROVIDER_DEFAULT_COLUMN_SPACING);
+  gtk_grid_set_row_spacing(grid,
+			   AGS_UI_PROVIDER_DEFAULT_ROW_SPACING);
+
+  gtk_box_append((GtkBox *) vbox,
+		 (GtkWidget *) grid);
 
   i = 0;
   
@@ -483,41 +523,67 @@ ags_pattern_envelope_init(AgsPatternEnvelope *pattern_envelope)
 				    "yalign", 1.0,
 				    NULL);
   gtk_grid_attach(grid,
-		  GTK_WIDGET(label),
-		  0, i,
+		  (GtkWidget *) label,
+		  0, 0,
 		  1, 1);
 
-  control = (GtkBox *) gtk_box_new(GTK_ORIENTATION_VERTICAL,
+  control = (GtkBox *) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,
 				   AGS_UI_PROVIDER_DEFAULT_SPACING);
-  gtk_grid_attach(grid,
-		  GTK_WIDGET(control),
-		  1, i,
-		  1, 1);
+
+  gtk_widget_set_hexpand((GtkWidget *) control,
+			 TRUE);
+  gtk_widget_set_vexpand((GtkWidget *) control,
+			 TRUE);
+
+  gtk_widget_set_halign((GtkWidget *) control,
+			GTK_ALIGN_FILL);
+  gtk_widget_set_valign((GtkWidget *) control,
+			GTK_ALIGN_FILL);
+
+  gtk_box_set_spacing(control,
+		      AGS_UI_PROVIDER_DEFAULT_SPACING);
   
-  pattern_envelope->attack_x = (GtkScale *) gtk_scale_new_with_range(GTK_ORIENTATION_HORIZONTAL,
-								     0.0, 1.0, 0.001);
-  gtk_widget_set_size_request(pattern_envelope->attack_x,
-			      (gint) (gui_scale_factor * AGS_PATTERN_ENVELOPE_SCALE_WIDTH), (gint) (gui_scale_factor * 16.0));
-  gtk_scale_set_draw_value((GtkScale *) pattern_envelope->attack_x,
-			   TRUE);
-  gtk_range_set_value((GtkRange *) pattern_envelope->attack_x,
-		      0.25);
+  gtk_grid_attach(grid,
+		  (GtkWidget *) control,
+		  1, 0,
+		  1, 1);
+
+  pattern_envelope->attack_x = ags_dial_new();
+
+  gtk_adjustment_set_lower(pattern_envelope->attack_x->adjustment,
+			   0.0);
+  gtk_adjustment_set_upper(pattern_envelope->attack_x->adjustment,
+			   1.0);
+  
+  gtk_adjustment_set_step_increment(pattern_envelope->attack_x->adjustment,
+				    0.001);
+  gtk_adjustment_set_page_increment(pattern_envelope->attack_x->adjustment,
+				    0.01);
+
+  gtk_adjustment_set_value(pattern_envelope->attack_x->adjustment,
+			   0.25);
+
   gtk_box_append(control,
 		 (GtkWidget *) pattern_envelope->attack_x);
 
-  pattern_envelope->attack_y = (GtkScale *) gtk_scale_new_with_range(GTK_ORIENTATION_HORIZONTAL,
-								     -1.0, 1.0, 0.001);
-  gtk_widget_set_size_request(pattern_envelope->attack_y,
-			      (gint) (gui_scale_factor * AGS_PATTERN_ENVELOPE_SCALE_WIDTH), (gint) (gui_scale_factor * 16.0));
-  gtk_scale_set_draw_value((GtkScale *) pattern_envelope->attack_y,
-			   TRUE);
-  gtk_range_set_value((GtkRange *) pattern_envelope->attack_y,
-		      0.0);
+  pattern_envelope->attack_y = ags_dial_new();
+
+  gtk_adjustment_set_lower(pattern_envelope->attack_y->adjustment,
+			   0.0);
+  gtk_adjustment_set_upper(pattern_envelope->attack_y->adjustment,
+			   1.0);
+  
+  gtk_adjustment_set_step_increment(pattern_envelope->attack_y->adjustment,
+				    0.001);
+  gtk_adjustment_set_page_increment(pattern_envelope->attack_y->adjustment,
+				    0.01);
+
+  gtk_adjustment_set_value(pattern_envelope->attack_y->adjustment,
+			   0.0);
+
   gtk_box_append(control,
 		 (GtkWidget *) pattern_envelope->attack_y);
 
-  i++;
-  
   /* decay */
   label = (GtkLabel *) g_object_new(GTK_TYPE_LABEL,
 				    "label", i18n("decay"),
@@ -526,40 +592,52 @@ ags_pattern_envelope_init(AgsPatternEnvelope *pattern_envelope)
 				    NULL);
   gtk_grid_attach(grid,
 		  GTK_WIDGET(label),
-		  0, i,
+		  0, 1,
 		  1, 1);
 
-  control = (GtkBox *) gtk_box_new(GTK_ORIENTATION_VERTICAL,
+  control = (GtkBox *) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,
 				   0);
   gtk_grid_attach(grid,
 		  GTK_WIDGET(control),
-		  1, i,
+		  1, 1,
 		  1, 1);
 
-  pattern_envelope->decay_x = (GtkScale *) gtk_scale_new_with_range(GTK_ORIENTATION_HORIZONTAL,
-								    0.0, 1.0, 0.001);
-  gtk_widget_set_size_request(pattern_envelope->decay_x,
-			      (gint) (gui_scale_factor * AGS_PATTERN_ENVELOPE_SCALE_WIDTH), (gint) (gui_scale_factor * 16.0));
-  gtk_scale_set_draw_value((GtkScale *) pattern_envelope->decay_x,
-			   TRUE);
-  gtk_range_set_value((GtkRange *) pattern_envelope->decay_x,
-		      0.25);
-  gtk_box_append(control,
+  pattern_envelope->decay_x = ags_dial_new();
+
+  gtk_adjustment_set_lower(pattern_envelope->decay_x->adjustment,
+			   0.0);
+  gtk_adjustment_set_upper(pattern_envelope->decay_x->adjustment,
+			   1.0);
+  
+  gtk_adjustment_set_step_increment(pattern_envelope->decay_x->adjustment,
+				    0.001);
+  gtk_adjustment_set_page_increment(pattern_envelope->decay_x->adjustment,
+				    0.01);
+
+  gtk_adjustment_set_value(pattern_envelope->decay_x->adjustment,
+			   0.25);
+
+  gtk_box_append((GtkBox *) control,
 		 (GtkWidget *) pattern_envelope->decay_x);
 
-  pattern_envelope->decay_y = (GtkScale *) gtk_scale_new_with_range(GTK_ORIENTATION_HORIZONTAL,
-								    -1.0, 1.0, 0.001);
-  gtk_widget_set_size_request(pattern_envelope->decay_y,
-			      (gint) (gui_scale_factor * AGS_PATTERN_ENVELOPE_SCALE_WIDTH), (gint) (gui_scale_factor * 16.0));
-  gtk_scale_set_draw_value((GtkScale *) pattern_envelope->decay_y,
-			   TRUE);
-  gtk_range_set_value((GtkRange *) pattern_envelope->decay_y,
-		      0.0);
-  gtk_box_append(control,
+  pattern_envelope->decay_y = ags_dial_new();
+
+  gtk_adjustment_set_lower(pattern_envelope->decay_y->adjustment,
+			   0.0);
+  gtk_adjustment_set_upper(pattern_envelope->decay_y->adjustment,
+			   1.0);
+  
+  gtk_adjustment_set_step_increment(pattern_envelope->decay_y->adjustment,
+				    0.001);
+  gtk_adjustment_set_page_increment(pattern_envelope->decay_y->adjustment,
+				    0.01);
+
+  gtk_adjustment_set_value(pattern_envelope->decay_y->adjustment,
+			   0.0);
+
+  gtk_box_append((GtkBox *) control,
 		 (GtkWidget *) pattern_envelope->decay_y);
 
-  i++;
-  
   /* sustain */
   label = (GtkLabel *) g_object_new(GTK_TYPE_LABEL,
 				    "label", i18n("sustain"),
@@ -568,40 +646,52 @@ ags_pattern_envelope_init(AgsPatternEnvelope *pattern_envelope)
 				    NULL);
   gtk_grid_attach(grid,
 		  GTK_WIDGET(label),
-		  0, i,
+		  0, 2,
 		  1, 1);
 
-  control = (GtkBox *) gtk_box_new(GTK_ORIENTATION_VERTICAL,
+  control = (GtkBox *) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,
 				   0);
   gtk_grid_attach(grid,
 		  GTK_WIDGET(control),
-		  1, i,
+		  1, 2,
 		  1, 1);
 
-  pattern_envelope->sustain_x = (GtkScale *) gtk_scale_new_with_range(GTK_ORIENTATION_HORIZONTAL,
-								      0.0, 1.0, 0.001);
-  gtk_widget_set_size_request(pattern_envelope->sustain_x,
-			      (gint) (gui_scale_factor * AGS_PATTERN_ENVELOPE_SCALE_WIDTH), (gint) (gui_scale_factor * 16.0));
-  gtk_scale_set_draw_value((GtkScale *) pattern_envelope->sustain_x,
-			   TRUE);
-  gtk_range_set_value((GtkRange *) pattern_envelope->sustain_x,
-		      0.25);
+  pattern_envelope->sustain_x = ags_dial_new();
+
+  gtk_adjustment_set_lower(pattern_envelope->sustain_x->adjustment,
+			   0.0);
+  gtk_adjustment_set_upper(pattern_envelope->sustain_x->adjustment,
+			   1.0);
+  
+  gtk_adjustment_set_step_increment(pattern_envelope->sustain_x->adjustment,
+				    0.001);
+  gtk_adjustment_set_page_increment(pattern_envelope->sustain_x->adjustment,
+				    0.01);
+
+  gtk_adjustment_set_value(pattern_envelope->sustain_x->adjustment,
+			   0.25);
+
   gtk_box_append(control,
 		 (GtkWidget *) pattern_envelope->sustain_x);
 
-  pattern_envelope->sustain_y = (GtkScale *) gtk_scale_new_with_range(GTK_ORIENTATION_HORIZONTAL,
-								      -1.0, 1.0, 0.001);
-  gtk_widget_set_size_request(pattern_envelope->sustain_y,
-			      (gint) (gui_scale_factor * AGS_PATTERN_ENVELOPE_SCALE_WIDTH), (gint) (gui_scale_factor * 16.0));
-  gtk_scale_set_draw_value((GtkScale *) pattern_envelope->sustain_y,
-			   TRUE);
-  gtk_range_set_value((GtkRange *) pattern_envelope->sustain_y,
-		      0.0);
+  pattern_envelope->sustain_y = ags_dial_new();
+
+  gtk_adjustment_set_lower(pattern_envelope->sustain_y->adjustment,
+			   0.0);
+  gtk_adjustment_set_upper(pattern_envelope->sustain_y->adjustment,
+			   1.0);
+  
+  gtk_adjustment_set_step_increment(pattern_envelope->sustain_y->adjustment,
+				    0.001);
+  gtk_adjustment_set_page_increment(pattern_envelope->sustain_y->adjustment,
+				    0.01);
+
+  gtk_adjustment_set_value(pattern_envelope->sustain_y->adjustment,
+			   0.0);
+
   gtk_box_append(control,
 		 (GtkWidget *) pattern_envelope->sustain_y);
 
-  i++;
-  
   /* release */
   label = (GtkLabel *) g_object_new(GTK_TYPE_LABEL,
 				    "label", i18n("release"),
@@ -610,40 +700,52 @@ ags_pattern_envelope_init(AgsPatternEnvelope *pattern_envelope)
 				    NULL);
   gtk_grid_attach(grid,
 		  GTK_WIDGET(label),
-		  0, i,
+		  0, 3,
 		  1, 1);
 
-  control = (GtkBox *) gtk_box_new(GTK_ORIENTATION_VERTICAL,
+  control = (GtkBox *) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,
 				   0);
   gtk_grid_attach(grid,
 		  GTK_WIDGET(control),
-		  1, i,
+		  1, 3,
 		  1, 1);
 
-  pattern_envelope->release_x = (GtkScale *) gtk_scale_new_with_range(GTK_ORIENTATION_HORIZONTAL,
-								      0.0, 1.0, 0.001);
-  gtk_widget_set_size_request(pattern_envelope->release_x,
-			      (gint) (gui_scale_factor * AGS_PATTERN_ENVELOPE_SCALE_WIDTH), (gint) (gui_scale_factor * 16.0));
-  gtk_scale_set_draw_value((GtkScale *) pattern_envelope->release_x,
-			   TRUE);
-  gtk_range_set_value((GtkRange *) pattern_envelope->release_x,
-		      0.25);
+  pattern_envelope->release_x = ags_dial_new();
+
+  gtk_adjustment_set_lower(pattern_envelope->release_x->adjustment,
+			   0.0);
+  gtk_adjustment_set_upper(pattern_envelope->release_x->adjustment,
+			   1.0);
+  
+  gtk_adjustment_set_step_increment(pattern_envelope->release_x->adjustment,
+				    0.001);
+  gtk_adjustment_set_page_increment(pattern_envelope->release_x->adjustment,
+				    0.01);
+
+  gtk_adjustment_set_value(pattern_envelope->release_x->adjustment,
+			   0.25);
+
   gtk_box_append(control,
 		 (GtkWidget *) pattern_envelope->release_x);
 
-  pattern_envelope->release_y = (GtkScale *) gtk_scale_new_with_range(GTK_ORIENTATION_HORIZONTAL,
-								      -1.0, 1.0, 0.001);
-  gtk_widget_set_size_request(pattern_envelope->release_y,
-			      (gint) (gui_scale_factor * AGS_PATTERN_ENVELOPE_SCALE_WIDTH), (gint) (gui_scale_factor * 16.0));
-  gtk_scale_set_draw_value((GtkScale *) pattern_envelope->release_y,
-			   TRUE);
-  gtk_range_set_value((GtkRange *) pattern_envelope->release_y,
-		      0.0);
+  pattern_envelope->release_y = ags_dial_new();
+
+  gtk_adjustment_set_lower(pattern_envelope->release_y->adjustment,
+			   0.0);
+  gtk_adjustment_set_upper(pattern_envelope->release_y->adjustment,
+			   1.0);
+  
+  gtk_adjustment_set_step_increment(pattern_envelope->release_y->adjustment,
+				    0.001);
+  gtk_adjustment_set_page_increment(pattern_envelope->release_y->adjustment,
+				    0.01);
+
+  gtk_adjustment_set_value(pattern_envelope->release_y->adjustment,
+			   0.0);
+
   gtk_box_append(control,
 		 (GtkWidget *) pattern_envelope->release_y);
 
-  i++;
-  
   /* ratio */
   label = (GtkLabel *) g_object_new(GTK_TYPE_LABEL,
 				    "label", i18n("ratio"),
@@ -652,22 +754,48 @@ ags_pattern_envelope_init(AgsPatternEnvelope *pattern_envelope)
 				    NULL);
   gtk_grid_attach(grid,
 		  GTK_WIDGET(label),
-		  0, i,
+		  0, 4,
 		  1, 1);
 
-  pattern_envelope->ratio = (GtkScale *) gtk_scale_new_with_range(GTK_ORIENTATION_HORIZONTAL,
-								  0.0, 1.0, 0.001);
-  gtk_widget_set_size_request(pattern_envelope->ratio,
-			      (gint) (gui_scale_factor * AGS_PATTERN_ENVELOPE_SCALE_WIDTH), (gint) (gui_scale_factor * 16.0));
-  gtk_scale_set_draw_value((GtkScale *) pattern_envelope->ratio,
-			   TRUE);
-  gtk_range_set_value((GtkRange *) pattern_envelope->ratio,
-		      1.0);
+  control = (GtkBox *) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,
+				   AGS_UI_PROVIDER_DEFAULT_SPACING);
+
+  gtk_widget_set_hexpand((GtkWidget *) control,
+			 TRUE);
+  gtk_widget_set_vexpand((GtkWidget *) control,
+			 TRUE);
+
+  gtk_widget_set_halign((GtkWidget *) control,
+			GTK_ALIGN_FILL);
+  gtk_widget_set_valign((GtkWidget *) control,
+			GTK_ALIGN_FILL);
+
+  gtk_box_set_spacing(control,
+		      AGS_UI_PROVIDER_DEFAULT_SPACING);
+  
   gtk_grid_attach(grid,
-		  GTK_WIDGET(pattern_envelope->ratio),
-		  1, i,
+		  (GtkWidget *) control,
+		  1, 4,
 		  1, 1);
 
+  pattern_envelope->ratio = ags_dial_new();
+
+  gtk_adjustment_set_lower(pattern_envelope->ratio->adjustment,
+			   0.0);
+  gtk_adjustment_set_upper(pattern_envelope->ratio->adjustment,
+			   1.0);
+  
+  gtk_adjustment_set_step_increment(pattern_envelope->ratio->adjustment,
+				    0.001);
+  gtk_adjustment_set_page_increment(pattern_envelope->ratio->adjustment,
+				    0.01);
+
+  gtk_adjustment_set_value(pattern_envelope->ratio->adjustment,
+			   1.0);
+
+  gtk_box_append(control,
+		 (GtkWidget *) pattern_envelope->ratio);
+
   /* rename dialog */
   pattern_envelope->rename = NULL;
   
@@ -1474,10 +1602,10 @@ ags_pattern_envelope_reset_control(AgsPatternEnvelope *pattern_envelope)
 
   val = (AgsComplex *) g_value_get_boxed(&value);  
   
-  gtk_range_set_value((GtkRange *) pattern_envelope->attack_x,
-		      val[0].real);
-  gtk_range_set_value((GtkRange *) pattern_envelope->attack_y,
-		      val[0].imag);
+  gtk_adjustment_set_value(pattern_envelope->attack_x->adjustment,
+			   val[0].real);
+  gtk_adjustment_set_value(pattern_envelope->attack_y->adjustment,
+			   val[0].imag);
 
   /* decay */
   g_value_reset(&value);
@@ -1499,10 +1627,10 @@ ags_pattern_envelope_reset_control(AgsPatternEnvelope *pattern_envelope)
 
   val = (AgsComplex *) g_value_get_boxed(&value);  
   
-  gtk_range_set_value((GtkRange *) pattern_envelope->decay_x,
-		      val[0].real);
-  gtk_range_set_value((GtkRange *) pattern_envelope->decay_y,
-		      val[0].imag);
+  gtk_adjustment_set_value(pattern_envelope->decay_x->adjustment,
+			   val[0].real);
+  gtk_adjustment_set_value(pattern_envelope->decay_y->adjustment,
+			   val[0].imag);
 
   /* sustain */
   g_value_reset(&value);
@@ -1524,10 +1652,10 @@ ags_pattern_envelope_reset_control(AgsPatternEnvelope *pattern_envelope)
 
   val = (AgsComplex *) g_value_get_boxed(&value);  
   
-  gtk_range_set_value((GtkRange *) pattern_envelope->sustain_x,
-		      val[0].real);
-  gtk_range_set_value((GtkRange *) pattern_envelope->sustain_y,
-		      val[0].imag);
+  gtk_adjustment_set_value(pattern_envelope->sustain_x->adjustment,
+			   val[0].real);
+  gtk_adjustment_set_value(pattern_envelope->sustain_y->adjustment,
+			   val[0].imag);
 
   /* release */
   g_value_reset(&value);
@@ -1549,10 +1677,10 @@ ags_pattern_envelope_reset_control(AgsPatternEnvelope *pattern_envelope)
 
   val = (AgsComplex *) g_value_get_boxed(&value);  
   
-  gtk_range_set_value((GtkRange *) pattern_envelope->release_x,
-		      val[0].real);
-  gtk_range_set_value((GtkRange *) pattern_envelope->release_y,
-		      val[0].imag);
+  gtk_adjustment_set_value(pattern_envelope->release_x->adjustment,
+			   val[0].real);
+  gtk_adjustment_set_value(pattern_envelope->release_y->adjustment,
+			   val[0].imag);
 
   /* ratio */
   g_value_reset(&value);
@@ -1574,8 +1702,8 @@ ags_pattern_envelope_reset_control(AgsPatternEnvelope *pattern_envelope)
 
   val = (AgsComplex *) g_value_get_boxed(&value);  
   
-  gtk_range_set_value((GtkRange *) pattern_envelope->ratio,
-		      val[0].imag);
+  gtk_adjustment_set_value(pattern_envelope->ratio->adjustment,
+			   val[0].imag);
 
   /* unset no update */
   pattern_envelope->flags &= (~AGS_PATTERN_ENVELOPE_NO_UPDATE);
